@@ -56,7 +56,7 @@ class Job(object):
 
     def poll(self):
         #return None for testing
-        return self.proc.poll()
+        return self.proc.channel.exit_status_ready()
 
 class JobDistributor(object):
     #Some static members.  Replace the elements of 
@@ -129,6 +129,7 @@ class JobDistributor(object):
         client = paramiko.SSHClient()
         client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
         username, machine = host.split("@")
+        print(f"Connecting to {username}@{machine}")
         client.connect(machine, username=username)
         stdin, stdout, stderr = client.exec_command(command["command"])
         
@@ -145,7 +146,7 @@ class JobDistributor(object):
         
         #p = subprocess.Popen(shlex.split(command_line))
         print('Submited to ' + host + ': ' + command["command"])
-        self.processes[command["category"]][host].append(Job(host, p, command["command"]))
+        self.processes[command["category"]][host].append(Job(host, stdout, command["command"]))
         self.totalJobs += 1
 
     def getHost(self, host_cat):
